@@ -1,11 +1,12 @@
 """The Apple Framework builds require their own customization."""
+
 from __future__ import annotations
 
 import logging
 import os
 import struct
 import subprocess
-from abc import ABCMeta, abstractmethod
+from abc import ABC, abstractmethod
 from pathlib import Path
 from textwrap import dedent
 
@@ -14,12 +15,15 @@ from virtualenv.create.via_global_ref.builtin.ref import (
     PathRefToDest,
     RefMust,
 )
+from virtualenv.create.via_global_ref.builtin.via_global_self_do import BuiltinViaGlobalRefMeta
 
-from .common import CPython, CPythonPosix, is_mac_os_framework
+from .common import CPython, CPythonPosix, is_mac_os_framework, is_macos_brew
 from .cpython3 import CPython3
 
+LOGGER = logging.getLogger(__name__)
 
-class CPythonmacOsFramework(CPython, metaclass=ABCMeta):
+
+class CPythonmacOsFramework(CPython, ABC):
     @classmethod
     def can_describe(cls, interpreter):
         return is_mac_os_framework(interpreter) and super().can_describe(interpreter)
@@ -74,7 +78,7 @@ class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
     @property
     def reload_code(self):
         result = super().reload_code
-        result = dedent(
+        return dedent(
             f"""
         # the bundled site.py always adds the global site package if we're on python framework build, escape this
         import sys
@@ -86,7 +90,6 @@ class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
             sys._framework = before
         """,
         )
-        return result
 
 
 def fix_mach_o(exe, current, new, max_size):
@@ -114,13 +117,13 @@ def fix_mach_o(exe, current, new, max_size):
     unneeded bits of information, however Mac OS X 10.5 and earlier cannot read this new Link Edit table format.
     """
     try:
-        logging.debug("change Mach-O for %s from %s to %s", exe, current, new)
+        LOGGER.debug("change Mach-O for %s from %s to %s", exe, current, new)
         _builtin_change_mach_o(max_size)(exe, current, new)
     except Exception as e:  # noqa: BLE001
-        logging.warning("Could not call _builtin_change_mac_o: %s. Trying to call install_name_tool instead.", e)
+        LOGGER.warning("Could not call _builtin_change_mac_o: %s. Trying to call install_name_tool instead.", e)
         try:
             cmd = ["install_name_tool", "-change", current, new, exe]
-            subprocess.check_call(cmd)  # noqa: S603
+            subprocess.check_call(cmd)
         except Exception:
             logging.fatal("Could not call install_name_tool -- you must have Apple's development tools installed")
             raise
@@ -207,7 +210,7 @@ def _builtin_change_mach_o(maxint):  # noqa: C901
 
         def do_macho(file, bits, endian):
             # Read Mach-O header (the magic number is assumed read by the caller)
-            cpu_type, cpu_sub_type, file_type, n_commands, size_of_commands, flags = read_data(file, endian, 6)
+            _cpu_type, _cpu_sub_type, _file_type, n_commands, _size_of_commands, _flags = read_data(file, endian, 6)
             # 64-bits header has one more field.
             if bits == 64:  # noqa: PLR2004
                 read_data(file, endian)
@@ -240,7 +243,7 @@ def _builtin_change_mach_o(maxint):  # noqa: C901
                 n_fat_arch = read_data(file, BIG_ENDIAN)
                 for _ in range(n_fat_arch):
                     # Read arch header
-                    cpu_type, cpu_sub_type, offset, size, align = read_data(file, BIG_ENDIAN, 5)
+                    _cpu_type, _cpu_sub_type, offset, size, _align = read_data(file, BIG_ENDIAN, 5)
                     do_file(file, offset, size)
             elif magic == MH_MAGIC:
                 do_macho(file, 32, BIG_ENDIAN)
@@ -259,7 +262,20 @@ def _builtin_change_mach_o(maxint):  # noqa: C901
     return mach_o_change
 
 
+class CPython3macOsBrew(CPython3, CPythonPosix):
+    @classmethod
+    def can_describe(cls, interpreter):
+        return is_macos_brew(interpreter) and super().can_describe(interpreter)
+
+    @classmethod
+    def setup_meta(cls, interpreter):  # noqa: ARG003
+        meta = BuiltinViaGlobalRefMeta()
+        meta.copy_error = "Brew disables copy creation: https://github.com/Homebrew/homebrew-core/issues/138159"
+        return meta
+
+
 __all__ = [
-    "CPythonmacOsFramework",
+    "CPython3macOsBrew",
     "CPython3macOsFramework",
+    "CPythonmacOsFramework",
 ]
